======
lyceum
======

Un paquet Python utile pour la programmation en lycée.


* Free software: ISC license
* Documentation: "https://benabel.frama.io/lyceum-py".


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
